Clojure only.

hive-tmux.events

Event registrations and fx handlers for tmux pane lifecycle.

Events: :tmux/pane-created — after pane is registered in state :tmux/pane-killed — after pane is killed and deregistered :tmux/task-dispatched — after task sent to pane :tmux/interrupt-sent — after C-c sent to pane :tmux/state-changed — after registry mutation

Effects: :tmux/log — log event via timbre

Event registrations and fx handlers for tmux pane lifecycle.

Events:
  :tmux/pane-created       — after pane is registered in state
  :tmux/pane-killed        — after pane is killed and deregistered
  :tmux/task-dispatched    — after task sent to pane
  :tmux/interrupt-sent     — after C-c sent to pane
  :tmux/state-changed      — after registry mutation

Effects:
  :tmux/log                — log event via timbre
raw docstring

ensure-init!clj

(ensure-init!)

Ensure the event system is initialized. Idempotent — safe to call multiple times.

Ensure the event system is initialized. Idempotent — safe to call multiple times.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries